*NOTE: In recent versions of Stata and/or reghdfe,
*the results of the estimates with both industry-by-year fixed effects and control variables
*-- in particular: Line 37 below --
*give different results from what is reported in the
*paper. These estimates appear to be numerically
*unstable using the most recent version of Stata and
*reghdfe. Many thanks to Sandra Heim for bringing this
*issue to our attention.
*Davidson Heath & Chris Mace, May 2022


*******Tables********





*Table 1:
use ftda_panel, replace
bysort gvkey: egen ever_has_tm = max(has_tm)
codebook gvkey if ever_has_tm==0
codebook gvkey if ever_has_tm==1
tabstat logsale logat ROA Q MB bklev capxat cashat ADsale RDat tm_stock age fnpats nrecalls, s(mean median sd count) c(s) by(has_tm)






*Table 2: profits
use ftda_panel, clear
preserve
drop if year < 1989 | year > 2002
reghdfe ROA post95#treated, a(gvkey year) cl(gvkey)
reghdfe ROA post95#treated Q ADsale RDat age log_tmstk, a(gvkey year) cl(gvkey)  
reghdfe ROA post95#treated, a(gvkey naics4#year) cl(gvkey)  
reghdfe ROA post95#treated Q ADsale RDat age log_tmstk, a(gvkey naics4#year) cl(gvkey)  
restore
preserve
drop if year < 1996
reghdfe ROA post02#famous02_21, a(gvkey naics4#year) cl(gvkey)  
reghdfe ROA post02#famous02_21 Q ADsale RDat age log_tmstk, a(gvkey naics4#year) cl(gvkey)  
restore
preserve
reghdfe ROA post95#treated post02#famous02_21, a(gvkey naics4#year) cl(gvkey)  
reghdfe ROA post95#treated post02#famous02_21 Q ADsale RDat age log_tmstk, a(gvkey naics4#year) cl(gvkey)  
restore







*Table 3: Recalls
use ftda_panel, clear
drop if year < 1989 | year > 2002
xtset gvkey year
xtlogit had_recall post95_x_treat logsale i.year, re vce(cl gvkey) dif
predict had_recallp if e(sample)
corr had_recall had_recallp if e(sample)
di r(rho)^2
reghdfe had_recall post95_x_treat logsale, a(gvkey naics4#year) cl(gvkey)
menbreg nrecalls post95_x_treat logsale i.year || gvkey: , vce(cl gvkey) dif
predict nrecallsp if e(sample)
corr nrecalls nrecallsp if e(sample)
di r(rho)^2
reghdfe logrecalls post95_x_treat logsale, a(gvkey naics4#year) cl(gvkey)
reghdfe logunits post95_x_treat logsale, a(gvkey naics4#year) cl(gvkey)
reghdfe logrecallval post95_x_treat logsale, a(gvkey naics4#year) cl(gvkey)
reghdfe frac_mfr_init post95_x_treat logsale, a(gvkey naics4#year) cl(gvkey)



*Table 4: innovation + new products
use ftda_panel, clear
drop if year < 1989 | year > 2002
merge 1:1 gvkey year using data/patent_counts, keep(match master) nogen
replace ncites_wt = 0 if ncites_wt==.
gen logcites = log(1+ncites_wt)
xtset gvkey year
reghdfe RDat post95_x_treat, a(gvkey naics4#year) cl(gvkey)
reghdfe log_pats post95_x_treat, a(gvkey naics4#year) cl(gvkey)
reghdfe logcites post95_x_treat, a(gvkey naics4#year) cl(gvkey)
reghdfe log_tsm post95_x_treat, a(gvkey naics4#year) cl(gvkey)
reghdfe newprod post95_x_treat, a(gvkey naics4#year) cl(gvkey)
reghdfe lognewprodannounce post95_x_treat, a(gvkey naics4#year) cl(gvkey)




*Table 5: entry & exit / product market dynamics
use entry_exit_classyr, replace
drop if year<1989 | year> 2002
reghdfe log_regs interact_frac, a(usclass year) cl(usclass) 
reghdfe log_expiries interact_frac, a(usclass year) cl(usclass) 
reghdfe log_nactiveTMs interact_frac, a(usclass year) cl(usclass) 
reghdfe log_regs interact_frac log_regs_pretrendquad, a(usclass year) cl(usclass) 
reghdfe log_expiries interact_frac log_expiries_pretrendquad, a(usclass year) cl(usclass) 
reghdfe log_nactiveTMs interact_frac log_nactiveTMs_pretrendquad, a(usclass year) cl(usclass) 
*
use entry_exit_classyr, replace
drop if year<1989 | year> 2002
reghdfe log_entries interact_frac, a(usclass year) cl(usclass) 
reghdfe log_exits interact_frac, a(usclass year) cl(usclass) 
reghdfe log_nfirms interact_frac, a(usclass year) cl(usclass) 
reghdfe log_entries interact_frac log_entries_pretrendquad, a(usclass year) cl(usclass) 
reghdfe log_exits interact_frac log_exits_pretrendquad, a(usclass year) cl(usclass) 
reghdfe log_nfirms interact_frac log_nfirms_pretrendquad, a(usclass year) cl(usclass) 





*Table 6: nonlinearity in response: entry threat:
use ftda_panel, clear
drop if year < 1989 | year > 2002
drop if Lerner_tercile95==.
reghdfe ROA c.post95_x_treat#i.Lerner_tercile95, a(gvkey naics4#year) cl(gvkey)
reghdfe had_recall c.post95_x_treat#i.Lerner_tercile95, a(gvkey naics4#year) cl(gvkey)
reghdfe logrecalls c.post95_x_treat#i.Lerner_tercile95, a(gvkey naics4#year) cl(gvkey)
reghdfe log_pats c.post95_x_treat#i.Lerner_tercile95, a(gvkey naics4#year) cl(gvkey)
reghdfe newprod c.post95_x_treat#i.Lerner_tercile95, a(gvkey naics4#year) cl(gvkey)


*Table 7: Product market strategy:
use ftda_panel, clear
drop if year < 1989 | year > 2002
reghdfe ADsale post95_x_treat, a(gvkey naics4#year) cl(gvkey)
reghdfe log_tms post95_x_treat, a(gvkey naics4#year) cl(gvkey)
reghdfe log_old_class post95_x_treat, a(gvkey naics4#year) cl(gvkey)
reghdfe log_new_class post95_x_treat, a(gvkey naics4#year) cl(gvkey)
reghdfe n_active_classes post95_x_treat, a(gvkey naics4#year) cl(gvkey)
reghdfe brand_extend post95_x_treat, a(gvkey naics4#year) cl(gvkey)
reghdfe frac_renewed post95_x_treat, a(gvkey naics4#year) cl(gvkey)










************************Figures**********************************





*Figure 2A
use ftda_panel, clear
drop if year < 1989
*require at least one pre- and one post-FTDA firmyear:
bysort gvkey: egen t1 = max(post95)
bysort gvkey: egen t2 = min(post95)
drop if t1==0 | t1==. | t2==1 | t2==.
reghdfe ROA , a(gvkey naics4#year) cl(gvkey) res(resid)
collapse (mean) resid (sem) SE = resid, by(year treated)
reshape wide resid SE, i(year) j(treated)
local dth = resid1[7]
replace resid1 = resid1 - `dth'
gen hi_1=resid1+1.96*SE1
gen low_1=resid1-1.96*SE1
local dth = resid0[7]
replace resid0 = resid0 - `dth'
gen hi_0=resid0+1.96*SE0
gen low_0=resid0-1.96*SE0
twoway line resid1  year , lcolor(black) lwidth(medthick) || ///
rcap hi_1 low_1 year, lcolor(black) lwidth(vvthin) || ///
line resid0  year, lcolor(red) lwidth(medthick) || ///
rcap hi_0 low_0 year , lcolor(black) lwidth(vvthin) legend(order(1 "Treated" 3 "Control")) legend(ring(1) position(6) col(2)) ///
xlabel(1989(1)2005, angle(45)) xline(1995.5 2002.5, lcolor(black) lpattern(dash)) yline(0, lcolor(black) lw(0.1)) ytitle("ROA") xtitle("Year") /// 
ylabel(-.01 "-1.00%" -.005 "-0.50%" 0 "0.00%" .005 "0.50%" .01 "1.00%" .015 "1.50%" .02 "2.00%", nogrid labsize(vsmall) angle(horizontal)) ///
text(.0175 1996.4 "FTDA", place(n)) text(.0175 2003.75 "Moseley", place(n))


*Figure 2B
use ftda_panel, clear
drop if year < 1982 | year > 1995
gen post88 = (year > 1988)
reghdfe ROA, a(gvkey naics4#year) cl(gvkey) res(resid)
collapse (mean) resid (sem) SE = resid, by(year famous88_21)
reshape wide resid SE, i(year) j(famous88_21)
local dth = resid1[7]
replace resid1 = resid1 - `dth'
gen hi_1=resid1+1.96*SE1
gen low_1=resid1-1.96*SE1
local dth = resid0[7]
replace resid0 = resid0 - `dth'
gen hi_0=resid0+1.96*SE0
gen low_0=resid0-1.96*SE0
twoway line resid1  year , lcolor(black) lwidth(medthick) || ///
rcap hi_1 low_1 year, lcolor(black) lwidth(vvthin) || ///
line resid0  year, lcolor(red) lwidth(medthick) || ///
rcap hi_0 low_0 year , lcolor(black) lwidth(vvthin) legend(order(1 "Treated" 3 "Control")) legend(ring(1) position(6) col(2)) ///
xlabel(1982(1)1995, angle(45)) xline(1988.5, lcolor(black) lpattern(dash)) ytitle("ROA") xtitle("Year") /// 
ylabel(-.015 "-1.50%" -.01 "-1.00%" -.005 "-0.50%" 0 "0.00%" .005 "0.50%" .01 "1.00%" .015 "1.50%" .02 "2.00%", nogrid labsize(vsmall) angle(horizontal)) ///
text(.0175 1989.25 "TLRA", place(n))  yline(0, lcolor(black) lw(0.1))


*Figure 3A
use ftda_panel, clear
drop if year < 1989 | year > 2005
bysort gvkey: egen t1 = max(post95)
bysort gvkey: egen t2 = min(post95)
drop if t1==0 | t1==. | t2==1 | t2==.
reghdfe logrecalls , a(gvkey naics4#year) cl(gvkey) res(resid)
collapse (mean) resid (sem) SE = resid, by(year famous95_21)
reshape wide resid SE, i(year) j(famous95_21)
local dth = resid1[7]
replace resid1 = resid1 - `dth'
gen hi_1=resid1+1.96*SE1
gen low_1=resid1-1.96*SE1
local dth = resid0[7]
replace resid0 = resid0 - `dth'
gen hi_0=resid0+1.96*SE0
gen low_0=resid0-1.96*SE0
twoway line resid1  year , lcolor(black) lwidth(medthick) || ///
rcap hi_1 low_1 year, lcolor(black) lwidth(vvthin) || ///
line resid0  year, lcolor(red) lwidth(medthick) || ///
rcap hi_0 low_0 year , lcolor(black) lwidth(vvthin) legend(order(1 "Treated" 3 "Control")) legend(ring(1) position(6) col(2)) ///
xlabel(1989(1)2005, angle(45)) xline(1995.5 2002.5, lcolor(black) lpattern(dash)) yline(0, lcolor(black) lw(0.1)) ytitle("log(Recalls + 1)")  xtitle("Year")  /// 
ylabel(-.02(.01).04, nogrid labsize(vsmall) angle(horizontal)) ///
text(.035 1996.4 "FTDA",fcolor(white) lcolor(white) box place(n)) text(.035 2003.75 "Moseley",box fcolor(white) lcolor(white)  place(n))


*Figure 3B
use ftda_panel, clear
drop if year < 1982 | year > 1995
reghdfe logrecalls, a(gvkey naics4#year) cl(gvkey) res(resid)
collapse (mean) resid (sem) SE = resid, by(year famous88_21)
reshape wide resid SE, i(year) j(famous88_21)
local dth = resid1[7]
replace resid1 = resid1 - `dth'
gen hi_1=resid1+1.96*SE1
gen low_1=resid1-1.96*SE1
local dth = resid0[7]
replace resid0 = resid0 - `dth'
gen hi_0=resid0+1.96*SE0
gen low_0=resid0-1.96*SE0
twoway line resid1  year , lcolor(black) lwidth(medthick) || ///
rcap hi_1 low_1 year, lcolor(black) lwidth(vvthin) || ///
line resid0  year, lcolor(red) lwidth(medthick) || ///
rcap hi_0 low_0 year, lcolor(black) lwidth(vvthin) legend(order(1 "Treated" 3 "Control")) legend(ring(1) position(6) col(2)) ///
xlabel(1982(1)1995, angle(45)) xline( 1988.5, lcolor(black) lpattern(dash)) ytitle("log(Recalls + 1)")  xtitle("Year") ylabel(-.04(.02).04) ///
text(.0375 1989.25 "TLRA",fcolor(white)) yline(0, lcolor(black) lw(0.1))


*Figure 4A
use ftda_panel, clear
drop if year < 1982 | year > 2005
drop if famous95_21==1 & famous88_21==0 | famous95_21==0 & famous88_21==1
reghdfe RDat , a(gvkey naics4#year) cl(gvkey) res(resid)
collapse (mean) resid (sem) SE = resid, by(year famous95_21)
reshape wide resid SE, i(year) j(famous95_21)
local dth = resid1[7]
replace resid1 = resid1 - `dth'
gen hi_1=resid1+1.96*SE1
gen low_1=resid1-1.96*SE1
local dth = resid0[7]
replace resid0 = resid0 - `dth'
gen hi_0=resid0+1.96*SE0
gen low_0=resid0-1.96*SE0
twoway line resid1  year , lcolor(black) lwidth(medthick) || ///
rcap hi_1 low_1 year, lcolor(black) lwidth(vvthin) || ///
line resid0  year, lcolor(red) lwidth(medthick) || ///
rcap hi_0 low_0 year, lcolor(black) lwidth(vvthin) legend(order(1 "Treated" 3 "Control")) legend(ring(1) position(6) col(2)) ///
xlabel(1982(2)2005, angle(45)) xline(1988.5 1995.5 2002.5, lcolor(black) lpattern(dash)) ytitle("R&D/Assets", height(5))  xtitle("Year")  /// 
 ylabel(-.006 "-0.6%" -.004 "-0.4%"  -.002 "-0.2%" 0 "0.0%" .002 "0.2%" .004 "0.4%", nogrid labsize(vsmall) angle(horizontal)) ///
text(.275 1996.65 "FTDA",fcolor(white) lcolor(white) box place(n)) text(.275 2004.05 "Moseley",box fcolor(white) lcolor(white)  place(n)) ///
text(.275 1989.6 "TLRA",box fcolor(white) lcolor(white)  place(n))  yline(0, lcolor(black) lw(0.1))


*Figure 4B
use ftda_panel,clear
drop if famous95_21==1 & famous88_21==0 | famous95_21==0 & famous88_21==1
menbreg fnpats i.year || gvkey: , vce(cl gvkey) diff
predict resid,pea
collapse (mean) resid (sem) SE = resid, by(year famous95_21)
reshape wide resid SE, i(year) j(famous95_21)
local dth = resid1[7]
replace resid1 = resid1 - `dth'
gen hi_1=resid1+1.96*SE1
gen low_1=resid1-1.96*SE1
local dth = resid0[7]
replace resid0 = resid0 - `dth'
gen hi_0=resid0+1.96*SE0
gen low_0=resid0-1.96*SE0
twoway line resid1  year , lcolor(black) lwidth(medthick) || ///
rcap hi_1 low_1 year, lcolor(black) lwidth(vvthin) || ///
line resid0  year, lcolor(red) lwidth(medthick) || ///
rcap hi_0 low_0 year, lcolor(black) lwidth(vvthin) legend(order(1 "Treated" 3 "Control")) legend(ring(1) position(6) col(2)) ///
xlabel(1982(2)2005, angle(45)) xline(1988.5 1995.5 2002.5, lcolor(black) lpattern(dash)) ytitle("New Patents Granted", height(-3))  xtitle("Year")  /// 
 ylabel(-.5(.1).2, nogrid labsize(vsmall) angle(horizontal))   ///
text(.175 1996.65 "FTDA",fcolor(white) lcolor(white) box place(n)) text(.175 2004.05 "Moseley",box fcolor(white) lcolor(white)  place(n)) ///
text(.175 1989.6 "TLRA",box fcolor(white) lcolor(white)  place(n))  yline(0, lcolor(black) lw(0.1))



*Figure 5A
use entry_exit_classyr, replace
reghdfe TMfirms_enter 1982.year#c.treatedfrac 1983.year#c.treatedfrac 1984.year#c.treatedfrac ///
                                1985.year#c.treatedfrac 1986.year#c.treatedfrac 1987.year#c.treatedfrac 1988.year#c.treatedfrac ///
                                1989.year#c.treatedfrac 1990.year#c.treatedfrac 1991.year#c.treatedfrac 1992.year#c.treatedfrac ///
                                1993.year#c.treatedfrac 1994.year#c.treatedfrac 1995.year#c.treatedfrac 1996.year#c.treatedfrac ///
                                1997.year#c.treatedfrac 1998.year#c.treatedfrac 1999.year#c.treatedfrac 2000.year#c.treatedfrac ///
                                2001.year#c.treatedfrac 2002.year#c.treatedfrac 2003.year#c.treatedfrac 2004.year#c.treatedfrac ///
                                2005.year#c.treatedfrac, a(usclass year) cl(usclass) noomit

coefplot,vertical  lcolor(black) lwidth(medthick)   coeflabels( 1982.year#c.treatedfrac = "1982" 1983.year#c.treatedfrac = " "  ///
                                1984.year#c.treatedfrac = "1984" 1985.year#c.treatedfrac = " " 1986.year#c.treatedfrac = "1986" 1987.year#c.treatedfrac = " " ///
                                1988.year#c.treatedfrac = "1988" 1989.year#c.treatedfrac = " " 1990.year#c.treatedfrac = "1990" 1991.year#c.treatedfrac = " "  ///
                                1992.year#c.treatedfrac = "1992" 1993.year#c.treatedfrac = " " 1994.year#c.treatedfrac = "1994"  ///
                                1995.year#c.treatedfrac = " " 1996.year#c.treatedfrac = "1996" 1997.year#c.treatedfrac = " " 1998.year#c.treatedfrac = "1998" ///
                                1999.year#c.treatedfrac = " " 2000.year#c.treatedfrac = "2000" 2001.year#c.treatedfrac = " " 2002.year#c.treatedfrac = "2002" ///
                                2003.year#c.treatedfrac = " " 2004.year#c.treatedfrac = "2004" 2005.year#c.treatedfrac = " "  ,angle(45)  ) recast(line)  ///
                                ciopts(recast(rcap rcap) lwidth(vvthin) lcolor(black)) ytitle("Firms Entering", height(5)) xtitle("Year") yline(0, lcolor(black) lwidth(vthin)) ///
                                 ylabel(-1500(500)0  , nogrid labsize(vsmall) angle(horizontal))  ///
                                xline(6.5 14.5 21.5, lcolor(black) lpattern(dash)) ///
                                text(-1800 13.3 "FTDA",fcolor(white) lcolor(white) box place(n)) text(-1800 20 "Moseley",box fcolor(white) lcolor(white)  place(n)) ///
                                text(-1800 5.4 "TLRA",box fcolor(white) lcolor(white)  place(n)) drop(_cons) base 


*Figure 5B
use entry_exit_classyr, replace
reghdfe nregs 1982.year#c.treatedfrac 1983.year#c.treatedfrac 1984.year#c.treatedfrac ///
                                1985.year#c.treatedfrac 1986.year#c.treatedfrac 1987.year#c.treatedfrac 1988.year#c.treatedfrac ///
                                1989.year#c.treatedfrac 1990.year#c.treatedfrac 1991.year#c.treatedfrac 1992.year#c.treatedfrac ///
                                1993.year#c.treatedfrac 1994.year#c.treatedfrac 1995.year#c.treatedfrac 1996.year#c.treatedfrac ///
                                1997.year#c.treatedfrac 1998.year#c.treatedfrac 1999.year#c.treatedfrac 2000.year#c.treatedfrac ///
                                2001.year#c.treatedfrac 2002.year#c.treatedfrac 2003.year#c.treatedfrac 2004.year#c.treatedfrac ///
                                2005.year#c.treatedfrac, a(usclass year) cl(usclass) noomit
coefplot, vertical lcolor(black) lwidth(medthick) coeflabels( 1982.year#c.treatedfrac = "1982" 1983.year#c.treatedfrac = " "  ///
                                1984.year#c.treatedfrac = "1984" 1985.year#c.treatedfrac = " " 1986.year#c.treatedfrac = "1986" 1987.year#c.treatedfrac = " " ///
                                1988.year#c.treatedfrac = "1988" 1989.year#c.treatedfrac = " " 1990.year#c.treatedfrac = "1990" 1991.year#c.treatedfrac = " "  ///
                                1991.year#c.treatedfrac = " " 1992.year#c.treatedfrac = "1992" 1993.year#c.treatedfrac = " " 1994.year#c.treatedfrac = "1994"  ///
                                1995.year#c.treatedfrac = " " 1996.year#c.treatedfrac = "1996" 1997.year#c.treatedfrac = " " 1998.year#c.treatedfrac = "1998" ///
                                1999.year#c.treatedfrac = " " 2000.year#c.treatedfrac = "2000" 2001.year#c.treatedfrac = " " 2002.year#c.treatedfrac = "2002" ///
                                2003.year#c.treatedfrac = " " 2004.year#c.treatedfrac = "2004" 2005.year#c.treatedfrac = " "  ,angle(45)) recast(line) ///
                                ciopts(recast(rcap rcap) lwidth(vvthin) lcolor(black)) ytitle("New Trademarks Registered", height(5)) xtitle("Year")  yline(0, lcolor(black) lwidth(vthin)) ///
                                 ylabel( -8000(2000)0  , nogrid labsize(vsmall) angle(horizontal)) ///
                                xline(6.5 14.5 21.5, lcolor(black) lpattern(dash)) ///
                                text(-8550 13.3 "FTDA",fcolor(white) lcolor(white) box place(n)) text(-8550 20 "Moseley",box fcolor(white) lcolor(white)  place(n)) ///
                                text(-8550 5.4 "TLRA",box fcolor(white) lcolor(white)  place(n)) drop(_cons) base



*Figure 6A
use ftda_panel, clear
drop if year < 1982 | year > 2005
drop if famous95_21==1 & famous88_21==0 | famous95_21==0 & famous88_21==1
reghdfe new_product , a(gvkey naics4#year) cl(gvkey) res(resid)
collapse (mean) resid (sem) SE = resid, by(year famous95_21)
reshape wide resid SE, i(year) j(famous95_21)
local dth = resid1[3]
replace resid1 = resid1 - `dth'
gen hi_1=resid1+1.96*SE1
gen low_1=resid1-1.96*SE1
local dth = resid0[3]
replace resid0 = resid0 - `dth'
gen hi_0=resid0+1.96*SE0
gen low_0=resid0-1.96*SE0
twoway line resid1  year , lcolor(black) lwidth(medthick) || ///
rcap hi_1 low_1 year, lcolor(black) lwidth(vvthin) || ///
line resid0  year, lcolor(red) lwidth(medthick) || ///
rcap hi_0 low_0 year, lcolor(black) lwidth(vvthin) legend(order(1 "Treated" 3 "Control")) legend(ring(1) position(6) col(2)) ///
xlabel(1982(2)2005, angle(45)) xline(1988.5 1995.5 2002.5, lcolor(black) lpattern(dash)) ytitle("Announced a New Product", height(5)) xtitle("Year") /// 
ylabel(-.04(.02).04, nogrid labsize(vsmall) angle(horizontal))   ///
text(.04 1996.65 "FTDA",fcolor(white) lcolor(white) box place(n)) text(.04 2004.05 "Moseley",box fcolor(white) lcolor(white)  place(n)) ///
text(.04 1989.6 "TLRA",box fcolor(white) lcolor(white)  place(n)) 


*Figure 6B
use ftda_panel, clear
drop if year < 1982 | year > 2005
drop if famous95_21==1 & famous88_21==0 | famous95_21==0 & famous88_21==1
reghdfe frac_new , a(gvkey naics4#year) cl(gvkey) res(resid)
collapse (mean) resid (sem) SE = resid, by(year famous95_21)
reshape wide resid SE, i(year) j(famous95_21)
local dth = resid1[7]
replace resid1 = resid1 - `dth'
gen hi_1=resid1+1.96*SE1
gen low_1=resid1-1.96*SE1
local dth = resid0[7]
replace resid0 = resid0 - `dth'
gen hi_0=resid0+1.96*SE0
gen low_0=resid0-1.96*SE0
twoway line resid1  year , lcolor(black) lwidth(medthick) || ///
rcap hi_1 low_1 year, lcolor(black) lwidth(vvthin) || ///
line resid0  year, lcolor(red) lwidth(medthick) || ///
rcap hi_0 low_0 year, lcolor(black) lwidth(vvthin) legend(order(1 "Treated" 3 "Control")) legend(ring(1) position(6) col(2)) ///
xlabel(1982(2)2005, angle(45)) xline(1988.5 1995.5 2002.5, lcolor(black) lpattern(dash)) ytitle("Fraction of Trademarks" "In New Classes", height(7.5))  xtitle("Year")  /// 
 ylabel(-.05 "-5%"  0 "0%" .05 "5%" .10 "10%" .15 "15%", nogrid labsize(vsmall) angle(horizontal)) ///
text(.155 1996.65 "FTDA",fcolor(white) lcolor(white) box place(n)) text(.155 2004.05 "Moseley",box fcolor(white) lcolor(white)  place(n)) ///
text(.155 1989.6 "TLRA",box fcolor(white) lcolor(white)  place(n)) 


